summaryrefslogtreecommitdiff
path: root/deps/v8/include/v8.h
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/include/v8.h')
-rw-r--r--deps/v8/include/v8.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/deps/v8/include/v8.h b/deps/v8/include/v8.h
index f64b38673..90c43831f 100644
--- a/deps/v8/include/v8.h
+++ b/deps/v8/include/v8.h
@@ -855,12 +855,15 @@ class V8EXPORT String : public Primitive {
* \param start The starting position within the string at which
* copying begins.
* \param length The number of bytes to copy from the string.
* \return The number of characters copied to the buffer
* excluding the NULL terminator.
*/
int Write(uint16_t* buffer, int start = 0, int length = -1) const; // UTF-16
int WriteAscii(char* buffer, int start = 0, int length = -1) const; // ASCII
- int WriteUtf8(char* buffer, int length = -1) const; // UTF-8
+ int WriteUtf8(char* buffer,
+ int length = -1,
+ int* nchars = NULL) const; // UTF-8
/**
* A zero length string.
@@ -855,12 +855,15 @@ class V8EXPORT String : public Primitive {
* copying begins.
* \param length The number of bytes to copy from the string.
- * \return The number of characters copied to the buffer
+ * \param nchars The number of characters written.
+ * \return The number of bytes copied to the buffer
* excluding the NULL terminator.
*/